# ConnectionStepPropsJsonSchema

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** | A string indicating the expected data type of the property&#39;s value. For example: boolean  | [optional]
**pattern** | **str** | A string indicating the expected pattern of the property&#39;s value. For example: ^\\\\d+$  | [optional]
**any_of** | [**list[ConnectionStepPropsAnyOf]**](ConnectionStepPropsAnyOf.md) | A series of arrays containing key-value pairs for the type and format combinations Stitch will accept as the property&#39;s value. F  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


